@@ -32,6 +32,7 @@ from .exceptions import (
     BadGateway,
     BotBlocked,
     BotKicked,
+    ChatNotFound,
     MigrateToChat,
     RestartingTelegram,
     RetryAfter,
@@ -109,23 +110,19 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         self._data: Final[dict[BotKey[Any] | str, object]] = {}
 
     @overload  # type: ignore[override]
-    def __getitem__(self, key: BotKey[T]) -> T:
-        ...
+    def __getitem__(self, key: BotKey[T]) -> T: ...
 
     @overload
-    def __getitem__(self, key: str) -> Any:
-        ...
+    def __getitem__(self, key: str) -> Any: ...
 
     def __getitem__(self, key: str | BotKey[T]) -> Any:
         return self._data[key]
 
     @overload  # type: ignore[override]
-    def __setitem__(self, key: BotKey[T], value: T) -> None:
-        ...
+    def __setitem__(self, key: BotKey[T], value: T) -> None: ...
 
     @overload
-    def __setitem__(self, key: str, value: Any) -> None:
-        ...
+    def __setitem__(self, key: str, value: Any) -> None: ...
 
     def __setitem__(self, key: str | BotKey[T], value: Any) -> None:
         self._data[key] = value
@@ -196,6 +193,8 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
             return BadGateway(error_code, description)
         elif BotBlocked.match(description):
             return BotBlocked(error_code, description)
+        elif ChatNotFound.match(description):
+            return ChatNotFound(error_code, description)
         elif BotKicked.match(description):
             return BotKicked(error_code, description)
         else:
@@ -332,7 +331,10 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
             user_id = update.pre_checkout_query.from_.id
         elif update.poll is not None:
             pass
-        elif update.poll_answer is not None:
+        elif (
+            update.poll_answer is not None
+            and update.poll_answer.user is not None
+        ):
             user_id = update.poll_answer.user.id
         elif update.my_chat_member is not None:
             assert update.my_chat_member.from_ is not None
@@ -407,12 +409,10 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         await self._group_limit.clear()
 
     @abstractmethod
-    async def start(self) -> None:
-        ...
+    async def start(self) -> None: ...
 
     @abstractmethod
-    async def stop(self) -> None:
-        ...
+    async def stop(self) -> None: ...
 
 
 class PollBot(Bot):
@@ -507,23 +507,19 @@ class Handler:
 
 @runtime_checkable
 class HandlerTableProtocol(Protocol):
-    def freeze(self) -> None:
-        ...
+    def freeze(self) -> None: ...
 
     @property
     @abstractmethod
-    def frozen(self) -> bool:
-        ...
+    def frozen(self) -> bool: ...
 
     @abstractmethod
     async def get_handler(
         self, bot: Bot, update: BotUpdate
-    ) -> HandlerCallable | None:
-        ...
+    ) -> HandlerCallable | None: ...
 
 
 @runtime_checkable
 class FilterProtocol(Protocol):
     @abstractmethod
-    async def check(self, bot: Bot, update: BotUpdate) -> bool:
-        ...
+    async def check(self, bot: Bot, update: BotUpdate) -> bool: ...
